#!/usr/bin/env python
# coding: utf8

import requests
import time


class Camera(object):
    def __init__(self, ip='10.5.5.9'):
        self._api_url = 'http://' + ip
        
        # Connection Test
        self.connection = self._test()

    def __repr__(self):
        return '<GoPro Camera [{0}]>'.format(self.connection)

    def _command_api(self, method='', params=''):
        if params:
            params = {'p': params}
        url = self._api_url + '/gp/gpControl' + method
        return self._api_call(url, params)

    def _api_call(self, url, params):
        try:
            r = requests.get(url, timeout=5.0, params=params)
            self.connection = 'OK'
            return r.content.json()
        except:
            self.connection = 'Not Connected'
            return {}

    def _test(self):
        ok = self.ok
        if ok:
            return 'OK'
        else:
            return 'Not Connected'
            
    def _debug(self):
        content = self._command_api()
        sections = [
            'status',
            'info',
            'commands',
            'modes',
            'display_hints',
            'version',
            'filters',
            'services',
        ]
        return content

    @property
    def ok(self):
        if self.status:
            return True
        else:
            return False

    @property
    def status(self):
        return self._command_api().get('status')

    @property
    def commands(self):
        return self._command_api().get('commands')

    @property
    def info(self):
        return self._command_api().get('info')

    #def silence(self):
    #    return self._command_api()

    def capture(self):
        return self._command_api('/command/shutter', '1')

    def mode(self, method):
        xmode = {
            'video': '0',
            'photo': '1',
            'burst': '2',
            'timelapse': '3',
        }
        method = method.lower()
        if method in xmode:
            method = xmode[method]
        return self._command_api('/command/xmode', method)

    def burst(self):
        self.mode('burst')
        self.capture()

    def photo(self):
        self.mode('photo')
        self.capture()

    def video(self):
        self.mode('video')
        self.capture()

    def timelapse(self):
        self.mode('timelapse')
        self.capture()

    def delete_all(self):
        return self._command_api('/command/storage/delete/all')

    def delete_last(self):
        return self._command_api('/command/storage/delete/last')

    def sleep(self):
        return self._command_api('/command/system/sleep')

    def locate(self, method='on'):
        status = {
            'on': '1',
            'off': '0',
        }
        method = method.lower()
        if method in status:
            method = status[method]
        return self._command_api('/command/system/locate', method)

    def factory_reset(self):
        return self._command_api('/command/system/factory/reset')

if __name__ == '__main__':
    camera = Camera()
    camera.photo()

    #camera._debug()
    #camera.sleep()
    #camera.mode('photo')



#!/usr/bin/env python
# coding: utf8

"""
geocoder library
~~~~~~~~~~~~~~~~
GoPro Camera Python module made easy.

>>> import gopro
>>> camera = gopro.camera()
>>> camera.photo()
"""

__title__ = 'gopro'
__author__ = 'Denis Carriere'
__author_email__ = 'carriere.denis@gmail.com'
__version__ = '0.0.1'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) 2014-2015 Denis Carriere'

from .api import camera



#!/usr/bin/python
# coding: utf8

import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist bdist_wheel upload')
    sys.exit()

version = '0.0.1'
requires = ['requests>=2.3.0']

with open('README.md') as f:
    readme = f.read()
with open('LICENSE') as f:
    license = f.read()

setup(
    name='gopro',
    version=version,
    description="GoPro Camera Python module made easy.",
    long_description=readme,
    author='Denis Carriere',
    author_email='carriere.denis@gmail.com',
    url='https://github.com/DenisCarriere/gopro',
    download_url='https://github.com/DenisCarriere/gopro/tarball/master',
    license=license,
    packages=['gopro'],
    package_data={'': ['LICENSE', 'README.md']},
    package_dir={'gopro': 'gopro'},
    include_package_data=True,
    install_requires=requires,
    zip_safe=False,
    keywords='gopro camera hero black',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Scientific/Engineering :: GIS',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ),
)
